@@ -36,9 +36,11 @@ class Binomial(Distribution):
     #       
 
     # TODO: define the init function
-    def __init__(self,p,n):
+    def __init__(self,p=0.5,n=20):
         self.p= p
         self.n=n
+        Distribution.__init__(self, self.calculate_mean(), self.calculate_stdev())
+
         # TODO: store the probability of the distribution in an instance variable p
         # TODO: store the size of the distribution in an instance variable n
         
@@ -56,7 +58,11 @@ class Binomial(Distribution):
             float: mean of the data set
     
         """
+        print("n {} p {}".format(self.n,self.p))
         mean = self.p * self.n
+        
+        print("mean")
+        print(mean)
         return mean
          
 
@@ -72,13 +78,16 @@ class Binomial(Distribution):
     
         """
         stdev = math.sqrt(self.n * self.p * (1 - self.p))
+        print("n {} p {}".format(self.n,self.p))
+        print("stdev")
+        print(stdev)
         return stdev
 
     # TODO: write a replace_stats_with_data() method according to the specifications below. The read_data_file() from the Generaldistribution class can read in a data
     # file. Because the Binomaildistribution class inherits from the Generaldistribution class,
     # you don't need to re-write this method. However,  the method
-    # doesn't update the mean or standard deviation of
-    # a distribution. Hence you are going to write a method that calculates n, p, mean and
+    # doesn't update the mean    or standard deviation of
+ # a distribution. Hence you are going to write a method that calculates n, p, mean and
     # standard deviation from a data set and then updates the n, p, mean and stdev attributes.
     # Assume that the data is a list of zeros and ones like [0 1 0 1 1 0 1]. 
     #
@@ -212,10 +221,16 @@ class Binomial(Distribution):
         
         # Hint: When adding two binomial distributions, the p value remains the same
         #   The new n value is the sum of the n values of the two distributions.
-        other_p = other.p
-        if other_p == self.p:
-            other.n = other.n + self.n
-        return other
+        
+        new_binomial = Binomial()
+        
+        
+        if other.p == self.p:
+            new_binomial.p =self.p
+            new_binomial.n = other.n + self.n
+        new_binomial.mean= new_binomial.calculate_mean()
+        new_binomial.stdev= new_binomial.calculate_stdev()
+        return new_binomial
     
     
     # use the __repr__ magic method to output the characteristics of the binomial distribution object.
@@ -229,7 +244,22 @@ class Binomial(Distribution):
             string: characteristics of the Binomial object
         
         """
-        return "mean {}, standard deviation {}, p {}, n {}".format(self.mean, self.stdev, self.p, self.n)
+        # TODO: Define the representation method so that the output looks like
+        #       mean 5, standard deviation 4.5, p .8, n 20
+        #
+        #       with the values replaced by whatever the actual distributions values are
+        #       The method should return a string in the expected format
+        print("Test: mean {}, standard deviation {}, p {}, n {}".\
+        format(self.mean, self.stdev, self.p, self.n))
+              
+        return "mean {}, standard deviation {}, p {}, n {}".\
+        format(self.mean, self.stdev, self.p, self.n)
+        #return "mean {}, standard deviation {}, p {}, n {}".\
+        #format(self.mean, self.stdev, self.p, self.n)
+        
+        
+        
+        
         """
         obj_dict = Binomial.__dict__
         #sorted_dict =   collections.OrderedDict(sorted(obj_dict.items()))
@@ -246,10 +276,6 @@ class Binomial(Distribution):
                                     
         return returned_string
         """
-        # TODO: Define the representation method so that the output looks like
-        #       mean 5, standard deviation 4.5, p .8, n 20
-        #
-        #       with the values replaced by whatever the actual distributions values are
-        #       The method should return a string in the expected format
+     
     
 
